/**
 * @license Apache-2.0
 * @copyright Cube Dev, Inc.
 * @fileoverview
 * prepareAnnotation function and related types definition.
 */
import { MetaConfig, MetaConfigMap } from './toConfigMap';
import { MemberType } from '../types/strings';
import { MemberExpression } from '../types/query';
type GranularityMeta = {
    name: string;
    title: string;
    interval: string;
    offset?: string;
    origin?: string;
};
/**
 * Annotation item for cube's member.
 */
type ConfigItem = {
    title: string;
    shortTitle: string;
    description: string;
    type: string;
    format: string;
    meta: any;
    drillMembers?: any[];
    drillMembersGrouped?: any;
    granularities?: GranularityMeta[];
};
/**
 * Returns annotations by MetaConfigMap and cube's member type.
 */
declare const annotation: (configMap: MetaConfigMap, memberType: MemberType) => (member: string | MemberExpression) => undefined | [string, ConfigItem];
/**
 * Returns annotations object by MetaConfigs and query.
 */
declare function prepareAnnotation(metaConfig: MetaConfig[], query: any): {
    measures: {
        [index: string]: unknown;
    };
    dimensions: {
        [index: string]: unknown;
    };
    segments: {
        [index: string]: unknown;
    };
    timeDimensions: {
        [index: string]: unknown;
    };
};
export default prepareAnnotation;
export { ConfigItem, GranularityMeta, annotation, prepareAnnotation, };
//# sourceMappingURL=prepareAnnotation.d.ts.map